@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-''' A python library to incrementally rotate files'''
+''' A python logrotate library'''
 
 import os
 import glob
@@ -10,7 +10,7 @@ __copyright__ = 'Copyright 2013, Kyle Laplante'
 __date__ = '07-07-2013'
 
 __license__ = 'GPL'
-__version__ = '1.1'
+__version__ = '1.2'
 __email__ = 'kyle.laplante@gmail.com'
 
 
@@ -22,11 +22,24 @@ class LogRotate:
 
     """This library is a simple logrotater (or file rotater).
 Simply pass in the path to the main logfile and this
-library will rotate all the logs by an increment of 1."""
+library will rotate all the logs by an increment of 1.
+Example:
+
+import logrotater
+
+rotater = logrotater.LogRotate(prefix='/home/kyle/p4.log', verbose=True)
+
+rotater.rotate()
+
+The prefix path should be the path of the main logfile without the .N extension.
+The previous example would rotate /home/kyle/p4.log.N to /home/kyle/p4.log.N+1,
+move /home/kyle/p4.log to /home/kyle/p4.log.1 and create a new empty /home/kyle/p4.log."""
 
     def __init__(self, *args, **kwargs):
 
-        '''Required kwargs: prefix="some path"'''
+        '''Required kwargs: prefix="some path"
+Optional kwargs: verbose=True
+If verbose is True then LogRotate will print what it is doing with each file.'''
 
         self.verbose = kwargs.get('verbose', False)
         for k, v in kwargs.items():
